@@ -420,10 +420,10 @@ class dyagram:
     def discover_eigrp_neighbors_ssh(self, device):
 
         try:
-            self.log.info("GETTING DEVICE TYPE")
+            self.log.info("GETTING DEVICE TYPE IN EIGRP NEIGHBORS SSH")
             os = self.get_device_type(device)
             if os:
-                self.log.info("GOT DEVICE TYPE")
+                self.log.info("GOT DEVICE TYPE  FROM get_device_type func IN EIGRP NEIGHBORS SSH")
                 nm_args = self.netmiko_args_template.copy()
                 nm_args['host'] = device
                 nm_args['device_type'] = os
@@ -435,10 +435,11 @@ class dyagram:
                 nm_args['host'] = device
                 nm_args['device_type'] = os
                 #raise Exception("Unable to determine OS.")
-            self.log.info("GOT DEVICE TYPE")
-
+                self.log.info("GOT DEVICE TYPE IN EIGRP NEIGHBORS SSH")
 
+            self.log.info("CREATING NETMIKO OBJ IN EIGRP NEIGHBORS SSH")
             dev = ConnectHandler(**nm_args)
+            self.log.info("CREATED NETMIKO OBJ IN EIGRP NEIGHBORS SSH")
 
             dev.enable()
 
